yakumo.cinder.v2.qos

Package yakumo :: Package cinder :: Package v2 :: Module qos |
[hide private]
[frames] | no frames]

# Module qos

source code

Resource class and its manager for QoS specifications on Block Storage V2 API

Classes | [hide private]
| Resource resource class for QoS specifications on Block Storage V2 API
| Manager manager class for QoS specifications on Block Storage V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.cinder.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('consumer'
      , 'consumer', mapper.Noop),]